@@ -91,8 +91,8 @@ efivar_defaults = {
         'guid' : guids.Shim,
     },
     'MokListTrusted' : {
-        'attr' : (EFI_VARIABLE_BOOTSERVICE_ACCESS |
-                  EFI_VARIABLE_RUNTIME_ACCESS),
+        'attr' : (EFI_VARIABLE_NON_VOLATILE |
+                  EFI_VARIABLE_BOOTSERVICE_ACCESS),
         'guid' : guids.Shim,
     },
     'SbatLevel' : {
@@ -130,7 +130,8 @@ boot_defaults = {
     'guid' : guids.EfiGlobalVariable,
 }
 
-sigdb_names = ("PK", "KEK", "db", "dbx", "MokList", "MokListX", "TlsCaCertificate")
+sigdb_names = ("PK", "KEK", "db", "dbx", "MokList", "MokListX", "TlsCaCertificate",
+               "MokListRT", "MokListXRT")
 bool_names  = ('SecureBootEnable', 'CustomMode')
 ascii_names = ('Lang', 'PlatformLang', 'SbatLevel')
 blist_names = ('BootOrder', 'BootNext')
@@ -453,7 +454,8 @@ class EfiVarList(collections.UserDict):
                                   guid = guids.OvmfEnrollDefaultKeys):
         self.add_cert('PK', guid, cert, True)
         self.add_cert('KEK', guid, cert, True)
-        self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK, False)
+        self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK_2011, False)
+        self.add_cert('KEK', guids.MicrosoftVendor, certs.MS_KEK_2023, False)
         self.add_dummy_dbx(guids.OvmfEnrollDefaultKeys)
 
     def enroll_platform_redhat(self):
@@ -464,11 +466,13 @@ class EfiVarList(collections.UserDict):
         self.enroll_platform_with_cert(pk.name)
 
     def add_microsoft_keys(self):
-        self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN, False)
-        self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD, False)
+        self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2011, False)
+        self.add_cert('db', guids.MicrosoftVendor, certs.MS_WIN_2023, False)
+        self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2011, False)
+        self.add_cert('db', guids.MicrosoftVendor, certs.MS_3RD_2023, False)
 
     def add_distro_keys(self, distro):
-        certlist = certs.DISTRO_CA.get(distro)
+        certlist = certs.DISTRO_CA.get(distro).get('certs')
         if not certlist:
             l = ', '.join(certs.DISTRO_CA.keys())
             raise RuntimeError(f'unknown distro: {distro} (valid: {l})')
